@@ -31,9 +31,8 @@
 #include <gst/gst.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
-#include <libxfce4panel/xfce-hvbox.h>
+#include <libxfce4ui/libxfce4ui.h>
+#include <libxfce4panel/libxfce4panel.h>
 
 #include "libxfce4mixer/libxfce4mixer.h"
 
@@ -237,9 +236,6 @@ xfce_mixer_plugin_size_changed (XfceMixerPlugin *mixer_plugin,
   /* Get the orientation of the panel */
   orientation = xfce_panel_plugin_get_orientation (mixer_plugin->plugin);
 
-  /* Resize the panel plugin */
-  gtk_widget_set_size_request (GTK_WIDGET (mixer_plugin->plugin), size, size);
-
   /* Determine size for the volume button icons */
   size -= 2 + 2 * MAX (mixer_plugin->button->style->xthickness, mixer_plugin->button->style->ythickness);
 
@@ -347,7 +343,7 @@ xfce_mixer_plugin_clicked (XfceMixerPlugin *mixer_plugin)
                                       GTK_STOCK_DIALOG_ERROR,
                                       NULL,
                                       _("No left-click command defined yet. You can change this in the plugin properties."),
-                                      XFCE_CUSTOM_STOCK_BUTTON, _("Properties"), GTK_STOCK_PREFERENCES, GTK_RESPONSE_ACCEPT,
+                                      XFCE_BUTTON_TYPE_MIXED, _("Properties"), GTK_STOCK_PREFERENCES, GTK_RESPONSE_ACCEPT,
                                       GTK_STOCK_CLOSE, GTK_RESPONSE_REJECT,
                                       NULL);
 
@@ -370,7 +366,7 @@ xfce_mixer_plugin_clicked (XfceMixerPlugin *mixer_plugin)
                                  mixer_plugin->command);
 
       /* Display error */
-      xfce_err (message);
+      xfce_dialog_show_error (NULL, NULL, "%s", message); 
 
       /* Free error message */
       g_free (message);
@@ -395,9 +391,12 @@ xfce_mixer_plugin_configure (XfceMixerPlugin *mixer_plugin)
   /* Warn user if no sound cards are available */
   if (G_UNLIKELY (g_list_length (xfce_mixer_get_cards ()) <= 0))
     {
-      xfce_err (_("GStreamer was unable to detect any sound devices. "
-                  "Some sound system specific GStreamer packages may "
-                  "be missing. It may also be a permissions problem."));
+      xfce_dialog_show_error (NULL,
+                              NULL,
+                              _("GStreamer was unable to detect any sound devices. "
+                              "Some sound system specific GStreamer packages may "
+                              "be missing. It may also be a permissions problem.")); 
+
     }
   else
     {
@@ -576,12 +575,9 @@ xfce_mixer_plugin_bus_message (GstBus          *bus,
                                XfceMixerPlugin *mixer_plugin)
 {
   GstMixerTrack      *track = NULL;
-  gdouble             volume;
-  gchar              *label;
-  gint               *volumes;
-  gint                num_channels;
   gboolean            mute;
   gboolean            record;
+  gchar              *label;
 
   /* Don't do anything if GstBus messages are to be ignored */
   if (G_UNLIKELY (mixer_plugin->ignore_bus_messages))
